chiark / gitweb /
Declare and document @conn_fd@.
[mLib] / conn.h
diff --git a/conn.h b/conn.h
index 09fb723ee71a190d073506f60581a72f8233187b..d381850030ecbeb20a59143e123eb1bc7f26f584 100644 (file)
--- a/conn.h
+++ b/conn.h
@@ -1,6 +1,6 @@
 /* -*-c-*-
  *
- * $Id: conn.h,v 1.2 1999/05/15 10:33:32 mdw Exp $
+ * $Id: conn.h,v 1.7 2003/11/29 19:10:53 mdw Exp $
  *
  * Nonblocking connect handling
  *
 /*----- Revision history --------------------------------------------------* 
  *
  * $Log: conn.h,v $
+ * Revision 1.7  2003/11/29 19:10:53  mdw
+ * Declare and document @conn_fd@.
+ *
+ * Revision 1.6  2001/06/22 19:35:20  mdw
+ * Interface change to @conn_init@ -- return error rather than calling the
+ * function.  This reduces the number of different environments the
+ * callback has to cope with, and the old behaviour is easily simulatable
+ * with the new, while simulating the new behaviour was awkward and
+ * painful.
+ *
+ * Revision 1.5  1999/12/10 23:42:04  mdw
+ * Change header file guard names.
+ *
+ * Revision 1.4  1999/05/26 21:08:01  mdw
+ * Remove redundant structure member.
+ *
+ * Revision 1.3  1999/05/23 12:12:46  mdw
+ * Interface change to make the `conn' selector useful for generic stream
+ * sockets rather than just IPv4 ones.
+ *
  * Revision 1.2  1999/05/15 10:33:32  mdw
  * Fix copyright notices.
  *
@@ -38,8 +58,8 @@
  *
  */
 
-#ifndef CONN_H
-#define CONN_H
+#ifndef MLIB_CONN_H
+#define MLIB_CONN_H
 
 #ifdef __cplusplus
   extern "C" {
 
 /*----- Header files ------------------------------------------------------*/
 
-#ifndef SEL_H
+#include <sys/types.h>
+#include <sys/socket.h>
+
+#ifndef MLIB_SEL_H
 #  include "sel.h"
 #endif
 
@@ -63,35 +86,49 @@ typedef struct conn {
 
 /*----- Functions provided ------------------------------------------------*/
 
-/* --- @conn_init@ --- *
+/* --- @conn_fd@ --- *
  *
  * Arguments:  @conn *c@ = pointer to connection block
  *             @sel_state *s@ = pointer to select state to attach to
- *             @unsigned long saddr@ = source IP address
- *             @unsigned short sport@ = source port
- *             @unsigned long daddr@ = destination IP address
- *             @unsigned short dport@ = destination port
+ *             @int fd@ = file descriptor of socket
  *             @void (*func)(int fd, void *p) = handler function
  *             @void *p@ = argument for the handler function
  *
  * Returns:    ---
  *
- * Use:                Sets up a nonblocking connect job.  The source address and
- *             port can be zero if you don't care.  When the connection
- *             completes, the handler function is called with the connected
- *             socket as an argument.  If the connect fails rather than
- *             completes, the handler is informed of this by being passed a
- *             negative file descriptor.  In either case, the select job is
- *             then removed.
+ * Use:                Sets up a nonblocking connect job.  The socket should have a
+ *             connect pending for it already.
+ */
+
+void conn_fd(conn */*c*/, sel_state */*s*/, int /*fd*/,
+            void (*/*func*/)(int /*fd*/, void */*p*/),
+            void */*p*/);
+
+/* --- @conn_init@ --- *
+ *
+ * Arguments:  @conn *c@ = pointer to connection block
+ *             @sel_state *s@ = pointer to select state to attach to
+ *             @int fd@ = file descriptor of socket to connect
+ *             @struct sockaddr *dst@ = destination address
+ *             @int dsz@ = size of destination address
+ *             @void (*func)(int fd, void *p) = handler function
+ *             @void *p@ = argument for the handler function
+ *
+ * Returns:    Zero on success, nonzero on failure.
+ *
+ * Use:                Sets up a nonblocking connect job.  The socket should already
+ *             be bound if you care about that sort of thing.  When the
+ *             connection completes, the handler function is called with the
+ *             connected socket as an argument.  If the connect fails rather
+ *             than completes, the socket is closed, and the handler is
+ *             informed of this by being passed a negative file descriptor.
+ *             In either case, the select job is then removed.
  */
 
-extern void conn_init(conn */*c*/, sel_state */*s*/,
-                     unsigned long /*saddr*/,
-                     unsigned short /*sport*/,
-                     unsigned long /*daddr*/,
-                     unsigned long /*dport*/,
-                     void (*/*func*/)(int /*fd*/, void */*p*/),
-                     void */*p*/);
+extern int conn_init(conn */*c*/, sel_state */*s*/, int /*fd*/,
+                    struct sockaddr */*dst*/, int /*dsz*/,
+                    void (*/*func*/)(int /*fd*/, void */*p*/),
+                    void */*p*/);
 
 /* --- @conn_kill@ --- *
  *